@@ -14,5 +14,5 @@ fi
 sudo apt update &&
   sudo apt upgrade -y &&
   sudo apt install nginx python3 python3-pip certbot python3-certbot-nginx -y &&
-  sudo certbot --domain $DOMAIN_NAME -m $VERIFICATION_EMAIL --non-interactive --nginx --agree-tos &&
+  sudo certbot --domain "$DOMAIN_NAME" -m "$VERIFICATION_EMAIL" --non-interactive --nginx --agree-tos &&
   echo 'All done'
